
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.23.11',
    'branch_nick': 'patch-0-Release__1_23_11_preparation',
    'revision_id': '8d26abbeafb7086d39e3c87ff73335a5189bc8d1',
    'revno': 10227
}
